summaryrefslogtreecommitdiff
path: root/setup-makefiles.sh
diff options
context:
space:
mode:
authorIsaac Chen <isaacchen@isaacchen.cn>2018-08-05 10:45:35 +0200
committerIsaac Chen <isaacchen@isaacchen.cn>2018-12-02 11:02:30 +0800
commit7a59c64c449b614b40fd4619bc29808afddfcab6 (patch)
treeef0a16f7fbf00b544ad8e05dfe2164f99a6e17a5 /setup-makefiles.sh
parent77e80990b207491c639b79307c9f0022790b9e04 (diff)
wayne-common: Convert into common tree
Signed-off-by: Isaac Chen <isaacchen@isaacchen.cn>
Diffstat (limited to 'setup-makefiles.sh')
-rwxr-xr-xsetup-makefiles.sh23
1 files changed, 19 insertions, 4 deletions
diff --git a/setup-makefiles.sh b/setup-makefiles.sh
index 49491c9..2c60846 100755
--- a/setup-makefiles.sh
+++ b/setup-makefiles.sh
@@ -17,7 +17,7 @@
set -e
-DEVICE=wayne
+DEVICE_COMMON=wayne-common
VENDOR=xiaomi
INITIAL_COPYRIGHT_YEAR=2018
@@ -35,13 +35,28 @@ if [ ! -f "$HELPER" ]; then
fi
. "$HELPER"
-# Initialize the helper
-setup_vendor "$DEVICE" "$VENDOR" "$LINEAGE_ROOT"
+# Initialize the common helper
+setup_vendor "$DEVICE_COMMON" "$VENDOR" "$LINEAGE_ROOT" true
# Copyright headers and guards
-write_headers
+write_headers "wayne"
write_makefiles "$MY_DIR"/proprietary-files.txt true
# Finish
write_footers
+
+if [ -s "$MY_DIR"/../$DEVICE/proprietary-files.txt ]; then
+ # Reinitialize the helper for device
+ INITIAL_COPYRIGHT_YEAR="$DEVICE_BRINGUP_YEAR"
+ setup_vendor "$DEVICE" "$VENDOR" "$LINEAGE_ROOT" false
+
+ # Copyright headers and guards
+ write_headers
+
+ # The standard device blobs
+ write_makefiles "$MY_DIR"/../$DEVICE/proprietary-files.txt true
+
+ # We are done!
+ write_footers
+fi